=========
Profanity
=========

.. image:: https://travis-ci.org/EnTeQuAk/unfromm.png?branch=master
        :target: https://travis-ci.org/EnTeQuAk/unfromm

.. image:: https://pypip.in/d/unfromm/badge.png
        :target: https://crate.io/packages/unfromm?version=latest
